# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class OtpDevice(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "number",
            "factor_id",
            "display_name",
        }
        
        class properties:
            factor_id = schemas.IntSchema
            display_name = schemas.StrSchema
            number = schemas.StrSchema
            verified = schemas.BoolSchema
            __annotations__ = {
                "factor_id": factor_id,
                "display_name": display_name,
                "number": number,
                "verified": verified,
            }
    
    number: MetaOapg.properties.number
    factor_id: MetaOapg.properties.factor_id
    display_name: MetaOapg.properties.display_name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["factor_id"]) -> MetaOapg.properties.factor_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["display_name"]) -> MetaOapg.properties.display_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verified"]) -> MetaOapg.properties.verified: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["factor_id", "display_name", "number", "verified", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["factor_id"]) -> MetaOapg.properties.factor_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["display_name"]) -> MetaOapg.properties.display_name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["number"]) -> MetaOapg.properties.number: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verified"]) -> typing.Union[MetaOapg.properties.verified, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["factor_id", "display_name", "number", "verified", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        number: typing.Union[MetaOapg.properties.number, str, ],
        factor_id: typing.Union[MetaOapg.properties.factor_id, decimal.Decimal, int, ],
        display_name: typing.Union[MetaOapg.properties.display_name, str, ],
        verified: typing.Union[MetaOapg.properties.verified, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OtpDevice':
        return super().__new__(
            cls,
            *_args,
            number=number,
            factor_id=factor_id,
            display_name=display_name,
            verified=verified,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.otp_device import OtpDevice
from onelogin.model.error import Error

from . import path

# Path params
UserIdSchema = schemas.IntSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'user_id': typing.Union[UserIdSchema, decimal.Decimal, int, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_user_id = api_client.PathParameter(
    name="user_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=UserIdSchema,
    required=True,
)
# body param
SchemaForRequestBodyApplicationJson = OtpDevice


request_body_otp_device = api_client.RequestBody(
    content={
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
)
_auth = [
    'OAuth2',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def status() -> typing.Type['Error']:
                return Error
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.AnyTypeSchema,
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                active = schemas.BoolSchema
                                default = schemas.BoolSchema
                                state_token = schemas.StrSchema
                                auth_factor_name = schemas.StrSchema
                                phone_number = schemas.StrSchema
                                type_display_name = schemas.StrSchema
                                needs_trigger = schemas.BoolSchema
                                user_display_name = schemas.StrSchema
                                id = schemas.IntSchema
                                __annotations__ = {
                                    "active": active,
                                    "default": default,
                                    "state_token": state_token,
                                    "auth_factor_name": auth_factor_name,
                                    "phone_number": phone_number,
                                    "type_display_name": type_display_name,
                                    "needs_trigger": needs_trigger,
                                    "user_display_name": user_display_name,
                                    "id": id,
                                }
                    
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["active"]) -> MetaOapg.properties.active: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["default"]) -> MetaOapg.properties.default: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["state_token"]) -> MetaOapg.properties.state_token: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["auth_factor_name"]) -> MetaOapg.properties.auth_factor_name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["phone_number"]) -> MetaOapg.properties.phone_number: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["type_display_name"]) -> MetaOapg.properties.type_display_name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["needs_trigger"]) -> MetaOapg.properties.needs_trigger: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["user_display_name"]) -> MetaOapg.properties.user_display_name: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["active", "default", "state_token", "auth_factor_name", "phone_number", "type_display_name", "needs_trigger", "user_display_name", "id", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["active"]) -> typing.Union[MetaOapg.properties.active, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["default"]) -> typing.Union[MetaOapg.properties.default, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["state_token"]) -> typing.Union[MetaOapg.properties.state_token, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["auth_factor_name"]) -> typing.Union[MetaOapg.properties.auth_factor_name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["phone_number"]) -> typing.Union[MetaOapg.properties.phone_number, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["type_display_name"]) -> typing.Union[MetaOapg.properties.type_display_name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["needs_trigger"]) -> typing.Union[MetaOapg.properties.needs_trigger, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["user_display_name"]) -> typing.Union[MetaOapg.properties.user_display_name, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["active", "default", "state_token", "auth_factor_name", "phone_number", "type_display_name", "needs_trigger", "user_display_name", "id", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                            active: typing.Union[MetaOapg.properties.active, bool, schemas.Unset] = schemas.unset,
                            default: typing.Union[MetaOapg.properties.default, bool, schemas.Unset] = schemas.unset,
                            state_token: typing.Union[MetaOapg.properties.state_token, str, schemas.Unset] = schemas.unset,
                            auth_factor_name: typing.Union[MetaOapg.properties.auth_factor_name, str, schemas.Unset] = schemas.unset,
                            phone_number: typing.Union[MetaOapg.properties.phone_number, str, schemas.Unset] = schemas.unset,
                            type_display_name: typing.Union[MetaOapg.properties.type_display_name, str, schemas.Unset] = schemas.unset,
                            needs_trigger: typing.Union[MetaOapg.properties.needs_trigger, bool, schemas.Unset] = schemas.unset,
                            user_display_name: typing.Union[MetaOapg.properties.user_display_name, str, schemas.Unset] = schemas.unset,
                            id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *_args,
                                active=active,
                                default=default,
                                state_token=state_token,
                                auth_factor_name=auth_factor_name,
                                phone_number=phone_number,
                                type_display_name=type_display_name,
                                needs_trigger=needs_trigger,
                                user_display_name=user_display_name,
                                id=id,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "status": status,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'Error': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["status", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['Error', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["status", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        status: typing.Union['Error', schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *_args,
            status=status,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor400ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _enroll_mfa_factor_oapg(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _enroll_mfa_factor_oapg(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def _enroll_mfa_factor_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _enroll_mfa_factor_oapg(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _enroll_mfa_factor_oapg(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Enroll a Factor
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_user_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        _fields = None
        _body = None
        if body is not schemas.unset:
            serialized_data = request_body_otp_device.serialize(body, content_type)
            _headers.add('Content-Type', content_type)
            if 'fields' in serialized_data:
                _fields = serialized_data['fields']
            elif 'body' in serialized_data:
                _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class EnrollMfaFactor(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def enroll_mfa_factor(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def enroll_mfa_factor(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def enroll_mfa_factor(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def enroll_mfa_factor(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def enroll_mfa_factor(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._enroll_mfa_factor_oapg(
            body=body,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def post(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def post(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...


    @typing.overload
    def post(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def post(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def post(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._enroll_mfa_factor_oapg(
            body=body,
            path_params=path_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from onelogin.paths.api_2_hooks_envs_envvar_id.get import ApiForget
from onelogin.paths.api_2_hooks_envs_envvar_id.put import ApiForput
from onelogin.paths.api_2_hooks_envs_envvar_id.delete import ApiFordelete


class Api2HooksEnvsEnvvarId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



from onelogin.paths.api_2_api_authorizations_api_auth_id.get import ApiForget
from onelogin.paths.api_2_api_authorizations_api_auth_id.put import ApiForput
from onelogin.paths.api_2_api_authorizations_api_auth_id.delete import ApiFordelete


class Api2ApiAuthorizationsApiAuthId(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    AUTH_OAUTH2_V2_TOKEN = "/auth/oauth2/v2/token"
    AUTH_OAUTH2_REVOKE = "/auth/oauth2/revoke"
    AUTH_RATE_LIMIT = "/auth/rate_limit"
    API_2_API_AUTHORIZATIONS = "/api/2/api_authorizations"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID = "/api/2/api_authorizations/{api_auth_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES = "/api/2/api_authorizations/{api_auth_id}/scopes"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_SCOPES_SCOPE_ID = "/api/2/api_authorizations/{api_auth_id}/scopes/{scope_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS = "/api/2/api_authorizations/{api_auth_id}/claims"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLAIMS_CLAIM_ID = "/api/2/api_authorizations/{api_auth_id}/claims/{claim_id}"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS = "/api/2/api_authorizations/{api_auth_id}/clients"
    API_2_API_AUTHORIZATIONS_API_AUTH_ID_CLIENTS_CLIENT_APP_ID = "/api/2/api_authorizations/{api_auth_id}/clients/{client_app_id}"
    API_1_EVENTS = "/api/1/events"
    API_1_EVENTS_EVENT_ID = "/api/1/events/{event_id}"
    API_1_EVENTS_TYPES = "/api/1/events/types"
    API_1_GROUPS = "/api/1/groups"
    API_1_GROUPS_GROUP_ID = "/api/1/groups/{group_id}"
    API_1_INVITES_GET_INVITE_LINK = "/api/1/invites/get_invite_link"
    API_1_INVITES_SEND_INVITE_LINK = "/api/1/invites/send_invite_link"
    API_1_USERS = "/api/1/users"
    API_1_USERS_USER_ID = "/api/1/users/{user_id}"
    API_1_USERS_USER_ID_APPS = "/api/1/users/{user_id}/apps"
    API_1_USERS_USER_ID_ROLES = "/api/1/users/{user_id}/roles"
    API_1_USERS_SET_PASSWORD_CLEAR_TEXT_USER_ID = "/api/1/users/set_password_clear_text/{user_id}"
    API_1_USERS_SET_PASSWORD_USING_SALT_USER_ID = "/api/1/users/set_password_using_salt/{user_id}"
    API_1_USERS_CUSTOM_ATTRIBUTES = "/api/1/users/custom_attributes"
    API_1_USERS_USER_ID_AUTH_FACTOR = "/api/1/users/{user_id}/auth_factor"
    API_1_USERS_USER_ID_LOGOUT = "/api/1/users/{user_id}/logout"
    API_1_USERS_USER_ID_LOCK_USER = "/api/1/users/{user_id}/lock_user"
    API_1_USERS_USER_ID_OTP_DEVICES = "/api/1/users/{user_id}/otp_devices"
    API_1_USERS_USER_ID_MFA_TOKEN = "/api/1/users/{user_id}/mfa_token"
    API_1_USERS_USER_ID_ADD_ROLES = "/api/1/users/{user_id}/add_roles"
    API_1_USERS_USER_ID_SET_STATE = "/api/1/users/{user_id}/set_state"
    API_1_USERS_USER_ID_REMOVE_ROLES = "/api/1/users/{user_id}/remove_roles"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID = "/api/1/users/{user_id}/otp_devices/{device_id}"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_VERIFY = "/api/1/users/{user_id}/otp_devices/{device_id}/verify"
    API_1_USERS_USER_ID_OTP_DEVICES_DEVICE_ID_TRIGGER = "/api/1/users/{user_id}/otp_devices/{device_id}/trigger"
    API_1_PRIVILEGES = "/api/1/privileges"
    API_1_PRIVILEGES_PRIVILEGE_ID = "/api/1/privileges/{privilege_id}"
    API_1_PRIVILEGES_PRIVILEGE_ID_ROLES = "/api/1/privileges/{privilege_id}/roles"
    API_1_PRIVILEGES_PRIVILEGE_ID_ROLES_ROLE_ID = "/api/1/privileges/{privilege_id}/roles/{role_id}"
    API_1_PRIVILEGES_PRIVILEGE_ID_USERS = "/api/1/privileges/{privilege_id}/users"
    API_1_PRIVILEGES_PRIVILEGE_ID_USERS_USER_ID = "/api/1/privileges/{privilege_id}/users/{user_id}"
    API_1_ROLES = "/api/1/roles"
    API_1_ROLES_ROLE_ID = "/api/1/roles/{role_id}"
    API_1_SAML_ASSERTION = "/api/1/saml_assertion"
    API_1_SAML_ASSERTION_VERIFY_FACTOR = "/api/1/saml_assertion/verify_factor"
    API_2_SAML_ASSERTION = "/api/2/saml_assertion"
    API_2_SAML_ASSERTION_VERIFY_FACTOR = "/api/2/saml_assertion/verify_factor"
    API_2_MAPPINGS = "/api/2/mappings"
    API_2_MAPPINGS_MAPPING_ID = "/api/2/mappings/{mapping_id}"
    API_2_MAPPINGS_CONDITIONS = "/api/2/mappings/conditions"
    API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_OPERATORS = "/api/2/mappings/conditions/{mapping_condition_value}/operators"
    API_2_MAPPINGS_CONDITIONS_MAPPING_CONDITION_VALUE_VALUES = "/api/2/mappings/conditions/{mapping_condition_value}/values"
    API_2_MAPPINGS_ACTIONS = "/api/2/mappings/actions"
    API_2_MAPPINGS_ACTIONS_MAPPING_ACTION_VALUE_VALUES = "/api/2/mappings/actions/{mapping_action_value}/values"
    API_2_MAPPINGS_SORT = "/api/2/mappings/sort"
    API_2_APPS = "/api/2/apps"
    API_2_APPS_APP_ID = "/api/2/apps/{app_id}"
    API_2_APPS_APP_ID_PARAMETERS_PARAMETER_ID = "/api/2/apps/{app_id}/parameters/{parameter_id}"
    API_2_APPS_APP_ID_USERS = "/api/2/apps/{app_id}/users"
    API_2_APPS_APP_ID_RULES = "/api/2/apps/{app_id}/rules"
    API_2_APPS_APP_ID_RULES_RULE_ID = "/api/2/apps/{app_id}/rules/{rule_id}"
    API_2_APPS_APP_ID_RULES_CONDITIONS = "/api/2/apps/{app_id}/rules/conditions"
    API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_OPERATORS = "/api/2/apps/{app_id}/rules/conditions/{rule_condition_value}/operators"
    API_2_APPS_APP_ID_RULES_CONDITIONS_RULE_CONDITION_VALUE_VALUES = "/api/2/apps/{app_id}/rules/conditions/{rule_condition_value}/values"
    API_2_APPS_APP_ID_RULES_ACTIONS = "/api/2/apps/{app_id}/rules/actions"
    API_2_APPS_APP_ID_RULES_ACTIONS_RULE_ACTION_VALUE_VALUES = "/api/2/apps/{app_id}/rules/actions/{rule_action_value}/values"
    API_2_APPS_APP_ID_RULES_SORT = "/api/2/apps/{app_id}/rules/sort"
    API_2_CONNECTORS = "/api/2/connectors"
    API_2_RISK_RULES = "/api/2/risk/rules"
    API_2_RISK_RULES_RULE_ID = "/api/2/risk/rules/{rule_id}"
    API_2_RISK_EVENTS = "/api/2/risk/events"
    API_2_RISK_SCORES = "/api/2/risk/scores"
    API_2_RISK_VERIFY = "/api/2/risk/verify"
    API_2_MFA_USERS_USER_ID_REGISTRATIONS_REGISTRATION_ID = "/api/2/mfa/users/{user_id}/registrations/{registration_id}"
    API_2_MFA_USERS_USER_ID_REGISTRATIONS = "/api/2/mfa/users/{user_id}/registrations"
    API_2_MFA_USERS_USER_ID_DEVICES = "/api/2/mfa/users/{user_id}/devices"
    API_2_MFA_USERS_USER_ID_DEVICES_DEVICE_ID = "/api/2/mfa/users/{user_id}/devices/{device_id}"
    API_2_MFA_USERS_USER_ID_VERIFICATIONS_VERIFICATION_ID = "/api/2/mfa/users/{user_id}/verifications/{verification_id}"
    API_2_MFA_USERS_USER_ID_VERIFICATIONS = "/api/2/mfa/users/{user_id}/verifications"
    API_2_MFA_USERS_USER_ID_FACTORS = "/api/2/mfa/users/{user_id}/factors"
    API_2_MFA_USERS_USER_ID_MFA_TOKEN = "/api/2/mfa/users/{user_id}/mfa_token"
    API_2_ROLES = "/api/2/roles"
    API_2_ROLES_ROLE_ID = "/api/2/roles/{role_id}"
    API_2_ROLES_ROLE_ID_APPS = "/api/2/roles/{role_id}/apps"
    API_2_ROLES_ROLE_ID_USERS = "/api/2/roles/{role_id}/users"
    API_2_ROLES_ROLE_ID_ADMINS = "/api/2/roles/{role_id}/admins"
    API_2_HOOKS = "/api/2/hooks"
    API_2_HOOKS_HOOK_ID = "/api/2/hooks/{hook_id}"
    API_2_HOOKS_HOOK_ID_LOGS = "/api/2/hooks/{hook_id}/logs"
    API_2_HOOKS_ENVS = "/api/2/hooks/envs"
    API_2_HOOKS_ENVS_ENVVAR_ID = "/api/2/hooks/envs/{envvar_id}"
    API_2_USERS = "/api/2/users"
    API_2_USERS_USER_ID = "/api/2/users/{user_id}"
    API_2_USERS_USER_ID_APPS = "/api/2/users/{user_id}/apps"
    API_2_BRANDING_BRANDS = "/api/2/branding/brands"
    API_2_BRANDING_BRANDS_BRAND_ID = "/api/2/branding/brands/{brand_id}"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES = "/api/2/branding/brands/{brand_id}/templates"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_ID = "/api/2/branding/brands/{brand_id}/templates/{template_id}"
    API_2_BRANDING_BRANDS_BRAND_ID_APPS = "/api/2/branding/brands/{brand_id}/apps"
    API_2_BRANDING_EMAIL_SETTINGS = "/api/2/branding/email_settings"
    API_2_BRANDING_BRANDS_BRAND_ID_TEMPLATES_TEMPLATE_TYPE_LOCALE = "/api/2/branding/brands/{brand_id}/templates/{template_type}/{locale}"
    API_2_BRANDING_BRANDS_MASTER_TEMPLATES_TEMPLATE_TYPE = "/api/2/branding/brands/master/templates/{template_type}"



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_users_user_id_add_roles.put import AddRolesToUser
from onelogin.paths.api_1_users.post import CreateUser
from onelogin.paths.api_1_users_user_id.delete import DeleteUser
from onelogin.paths.api_1_users_custom_attributes.get import GetCustomAttributes
from onelogin.paths.api_1_users_user_id_apps.get import GetUserApps
from onelogin.paths.api_1_users_user_id.get import GetUserById
from onelogin.paths.api_1_users_user_id_roles.get import GetUserRoles
from onelogin.paths.api_1_users.get import ListUsers
from onelogin.paths.api_1_users_user_id_lock_user.put import LockAccountUser
from onelogin.paths.api_1_users_user_id_logout.put import LogOutUser
from onelogin.paths.api_1_users_user_id_remove_roles.put import RemoveUserRole
from onelogin.paths.api_1_users_user_id_set_state.put import SetUserState
from onelogin.paths.api_1_users_set_password_clear_text_user_id.put import UpdatePasswordInsecure
from onelogin.paths.api_1_users_set_password_using_salt_user_id.put import UpdatePasswordSecure
from onelogin.paths.api_1_users_user_id.put import UpdateUser


class UsersV1Api(
    AddRolesToUser,
    CreateUser,
    DeleteUser,
    GetCustomAttributes,
    GetUserApps,
    GetUserById,
    GetUserRoles,
    ListUsers,
    LockAccountUser,
    LogOutUser,
    RemoveUserRole,
    SetUserState,
    UpdatePasswordInsecure,
    UpdatePasswordSecure,
    UpdateUser,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_apps_app_id_rules.post import CreateAppRule
from onelogin.paths.api_2_apps_app_id_rules_rule_id.delete import DeleteRule
from onelogin.paths.api_2_apps_app_id_rules_rule_id.get import GetAppRule
from onelogin.paths.api_2_apps_app_id_rules_actions_rule_action_value_values.get import ListActionValies
from onelogin.paths.api_2_apps_app_id_rules_actions.get import ListActions
from onelogin.paths.api_2_apps_app_id_rules.get import ListAppRules
from onelogin.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_operators.get import ListConditionOperators
from onelogin.paths.api_2_apps_app_id_rules_conditions_rule_condition_value_values.get import ListConditionValues
from onelogin.paths.api_2_apps_app_id_rules_conditions.get import ListConditions
from onelogin.paths.api_2_apps_app_id_rules_sort.put import SortAppRules
from onelogin.paths.api_2_apps_app_id_rules_rule_id.put import UpdateAppRule


class AppRulesApi(
    CreateAppRule,
    DeleteRule,
    GetAppRule,
    ListActionValies,
    ListActions,
    ListAppRules,
    ListConditionOperators,
    ListConditionValues,
    ListConditions,
    SortAppRules,
    UpdateAppRule,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from onelogin.paths.api_2_api_authorizations.get import ApiForget
from onelogin.paths.api_2_api_authorizations.post import ApiForpost


class Api2ApiAuthorizations(
    ApiForget,
    ApiForpost,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.paths.api_2_roles_role_id_users import Api

from onelogin.paths import PathValues

path = PathValues.API_2_ROLES_ROLE_ID_USERS